@@ -24,7 +24,7 @@ import (
 	"errors"
 	"io"
 
-	"github.com/apache/trafficcontrol/cache-config/t3cutil"
+	"github.com/apache/trafficcontrol/v8/cache-config/t3cutil"
 )
 
 func WriteConfigs(configs []t3cutil.ATSConfigFile, output io.Writer) error {
