@@ -21,7 +21,7 @@ package crconfig
  */
 
 import (
-	"github.com/apache/trafficcontrol/lib/go-tc"
+	"github.com/apache/trafficcontrol/v8/lib/go-tc"
 )
 
 type ThsT *tc.CRConfig
