@@ -24,7 +24,7 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/apache/trafficcontrol/lib/go-tc"
+	"github.com/apache/trafficcontrol/v8/lib/go-tc"
 )
 
 type CfgMeta struct {
@@ -34,18 +34,25 @@ type CfgMeta struct {
 
 // ConfigFilesListOpts contains settings to configure generation options.
 type ConfigFilesListOpts struct {
+	// ATSMajorVersion is the integral major version of Apache Traffic server,
+	// used to generate the proper config for the proper version.
+	//
+	// If omitted or 0, the major version will be read from the Server's Profile Parameter config file 'package' name 'trafficserver'. If no such Parameter exists, the ATS version will default to 5.
+	// This was the old Traffic Control behavior, before the version was specifiable externally.
+	//
+	ATSMajorVersion uint
 }
 
 // MakeMetaObj returns the list of config files, any warnings, and any errors.
 func MakeConfigFilesList(
 	configDir string,
 	server *Server,
-	serverParams []tc.Parameter,
+	serverParams []tc.ParameterV5,
 	deliveryServices []DeliveryService,
 	deliveryServiceServers []DeliveryServiceServer,
-	globalParams []tc.Parameter,
-	cacheGroupArr []tc.CacheGroupNullable,
-	topologies []tc.Topology,
+	globalParams []tc.ParameterV5,
+	cacheGroupArr []tc.CacheGroupNullableV5,
+	topologies []tc.TopologyV5,
 	opt *ConfigFilesListOpts,
 ) ([]CfgMeta, []string, error) {
 	if opt == nil {
@@ -53,26 +60,25 @@ func MakeConfigFilesList(
 	}
 	warnings := []string{}
 
-	if server.Cachegroup == nil {
+	if server.CacheGroup == "" {
 		return nil, warnings, errors.New("this server missing Cachegroup")
-	} else if server.CachegroupID == nil {
+	} else if server.CacheGroupID == 0 {
 		return nil, warnings, errors.New("this server missing CachegroupID")
 	} else if server.TCPPort == nil {
 		return nil, warnings, errors.New("server missing TCPPort")
-	} else if server.HostName == nil {
+	} else if server.HostName == "" {
 		return nil, warnings, errors.New("server missing HostName")
-	} else if server.CDNID == nil {
+	} else if server.CDNID == 0 {
 		return nil, warnings, errors.New("server missing CDNID")
-	} else if server.CDNName == nil {
+	} else if server.CDN == "" {
 		return nil, warnings, errors.New("server missing CDNName")
-	} else if server.ID == nil {
+	} else if server.ID == 0 {
 		return nil, warnings, errors.New("server missing ID")
-	} else if len(server.ProfileNames) == 0 {
+	} else if len(server.Profiles) == 0 {
 		return nil, warnings, errors.New("server missing Profile")
 	}
 
-	atsMajorVer, verWarns := getATSMajorVersion(serverParams)
-	warnings = append(warnings, verWarns...)
+	atsMajorVersion := getATSMajorVersion(opt.ATSMajorVersion, serverParams, &warnings)
 
 	dses, dsWarns := filterConfigFileDSes(server, deliveryServices, deliveryServiceServers)
 	warnings = append(warnings, dsWarns...)
@@ -129,7 +135,7 @@ locationParamsFor:
 		configFiles = append(configFiles, atsCfg)
 	}
 
-	configFiles, configDirWarns, err := addMetaObjConfigDir(configFiles, configDir, server, locationParams, uriSignedDSes, dses, cacheGroupArr, topologies, atsMajorVer)
+	configFiles, configDirWarns, err := addMetaObjConfigDir(configFiles, configDir, server, locationParams, uriSignedDSes, dses, cacheGroupArr, topologies, atsMajorVersion)
 	warnings = append(warnings, configDirWarns...)
 	return configFiles, warnings, err
 }
@@ -146,13 +152,13 @@ func addMetaObjConfigDir(
 	locationParams map[string]configProfileParams, // map[configFile]params; 'location' and 'URL' Parameters on serverHostName's Profile
 	uriSignedDSes []tc.DeliveryServiceName,
 	dses map[tc.DeliveryServiceName]DeliveryService,
-	cacheGroupArr []tc.CacheGroupNullable,
-	topologies []tc.Topology,
-	atsMajorVer int,
+	cacheGroupArr []tc.CacheGroupNullableV5,
+	topologies []tc.TopologyV5,
+	atsMajorVersion uint,
 ) ([]CfgMeta, []string, error) {
 	warnings := []string{}
 
-	if server.Cachegroup == nil {
+	if server.CacheGroup == "" {
 		return nil, warnings, errors.New("server missing Cachegroup")
 	}
 
@@ -171,7 +177,7 @@ func addMetaObjConfigDir(
 	// If they don't exist, create them.
 	// If they exist with a relative path, prepend configDir.
 	// If any exist with a relative path, or don't exist, and configDir is empty, return an error.
-	for _, fileName := range requiredFiles(atsMajorVer) {
+	for _, fileName := range requiredFiles(atsMajorVersion) {
 		if _, ok := configFilesM[fileName]; ok {
 			continue
 		}
@@ -202,7 +208,7 @@ func addMetaObjConfigDir(
 	nameTopologies := makeTopologyNameMap(topologies)
 
 	for _, ds := range dses {
-		if ds.XMLID == nil {
+		if ds.XMLID == "" {
 			warnings = append(warnings, "got Delivery Service with nil XMLID - not considering!")
 			continue
 		}
@@ -213,13 +219,13 @@ func addMetaObjConfigDir(
 		if ds.Topology != nil && *ds.Topology != "" {
 			topology := nameTopologies[TopologyName(*ds.Topology)]
 
-			placement, err := getTopologyPlacement(tc.CacheGroupName(*server.Cachegroup), topology, cacheGroups, &ds)
+			placement, err := getTopologyPlacement(tc.CacheGroupName(server.CacheGroup), topology, cacheGroups, &ds)
 			if err != nil {
 				return nil, warnings, errors.New("getting topology placement: " + err.Error())
 			}
 			if placement.IsFirstCacheTier {
 				if (ds.FirstHeaderRewrite != nil && *ds.FirstHeaderRewrite != "") || ds.MaxOriginConnections != nil || ds.ServiceCategory != nil {
-					fileName := FirstHeaderRewriteConfigFileName(*ds.XMLID)
+					fileName := FirstHeaderRewriteConfigFileName(ds.XMLID)
 					if configFilesM, err = ensureConfigFile(configFilesM, fileName, configDir); err != nil {
 						warnings = append(warnings, "ensuring config file '"+fileName+"': "+err.Error())
 					}
@@ -227,7 +233,7 @@ func addMetaObjConfigDir(
 			}
 			if placement.IsInnerCacheTier {
 				if (ds.InnerHeaderRewrite != nil && *ds.InnerHeaderRewrite != "") || ds.MaxOriginConnections != nil || ds.ServiceCategory != nil {
-					fileName := InnerHeaderRewriteConfigFileName(*ds.XMLID)
+					fileName := InnerHeaderRewriteConfigFileName(ds.XMLID)
 					if configFilesM, err = ensureConfigFile(configFilesM, fileName, configDir); err != nil {
 						warnings = append(warnings, "ensuring config file '"+fileName+"': "+err.Error())
 					}
@@ -235,7 +241,7 @@ func addMetaObjConfigDir(
 			}
 			if placement.IsLastCacheTier {
 				if (ds.LastHeaderRewrite != nil && *ds.LastHeaderRewrite != "") || ds.MaxOriginConnections != nil || ds.ServiceCategory != nil {
-					fileName := LastHeaderRewriteConfigFileName(*ds.XMLID)
+					fileName := LastHeaderRewriteConfigFileName(ds.XMLID)
 					if configFilesM, err = ensureConfigFile(configFilesM, fileName, configDir); err != nil {
 						warnings = append(warnings, "ensuring config file '"+fileName+"': "+err.Error())
 					}
@@ -244,35 +250,35 @@ func addMetaObjConfigDir(
 		} else if strings.HasPrefix(server.Type, tc.EdgeTypePrefix) {
 			if (ds.EdgeHeaderRewrite != nil || ds.MaxOriginConnections != nil || ds.ServiceCategory != nil) &&
 				strings.HasPrefix(server.Type, tc.EdgeTypePrefix) {
-				fileName := "hdr_rw_" + *ds.XMLID + ".config"
+				fileName := "hdr_rw_" + ds.XMLID + ".config"
 				if configFilesM, err = ensureConfigFile(configFilesM, fileName, configDir); err != nil {
 					warnings = append(warnings, "ensuring config file '"+fileName+"': "+err.Error())
 				}
 			}
 		} else if strings.HasPrefix(server.Type, tc.MidTypePrefix) {
 			if (ds.MidHeaderRewrite != nil || ds.MaxOriginConnections != nil || ds.ServiceCategory != nil) &&
-				ds.Type != nil && ds.Type.UsesMidCache() &&
+				ds.Type != nil && tc.DSType(*ds.Type).UsesMidCache() &&
 				strings.HasPrefix(server.Type, tc.MidTypePrefix) {
-				fileName := "hdr_rw_mid_" + *ds.XMLID + ".config"
+				fileName := "hdr_rw_mid_" + ds.XMLID + ".config"
 				if configFilesM, err = ensureConfigFile(configFilesM, fileName, configDir); err != nil {
 					warnings = append(warnings, "ensuring config file '"+fileName+"': "+err.Error())
 				}
 			}
 		}
 		if ds.RegexRemap != nil {
-			configFile := "regex_remap_" + *ds.XMLID + ".config"
+			configFile := "regex_remap_" + ds.XMLID + ".config"
 			if configFilesM, err = ensureConfigFile(configFilesM, configFile, configDir); err != nil {
 				warnings = append(warnings, "ensuring config file '"+configFile+"': "+err.Error())
 			}
 		}
 		if ds.SigningAlgorithm != nil && *ds.SigningAlgorithm == tc.SigningAlgorithmURLSig {
-			configFile := "url_sig_" + *ds.XMLID + ".config"
+			configFile := "url_sig_" + ds.XMLID + ".config"
 			if configFilesM, err = ensureConfigFile(configFilesM, configFile, configDir); err != nil {
 				warnings = append(warnings, "ensuring config file '"+configFile+"': "+err.Error())
 			}
 		}
 		if ds.SigningAlgorithm != nil && *ds.SigningAlgorithm == tc.SigningAlgorithmURISigning {
-			configFile := "uri_signing_" + *ds.XMLID + ".config"
+			configFile := "uri_signing_" + ds.XMLID + ".config"
 			if configFilesM, err = ensureConfigFile(configFilesM, configFile, configDir); err != nil {
 				warnings = append(warnings, "ensuring config file '"+configFile+"': "+err.Error())
 			}
@@ -298,17 +304,17 @@ func getURISignedDSes(dses map[tc.DeliveryServiceName]DeliveryService) ([]tc.Del
 			warnings = append(warnings, "got delivery service with no id, skipping!")
 			continue
 		}
-		if ds.XMLID == nil {
+		if ds.XMLID == "" {
 			warnings = append(warnings, "got delivery service with no xmlId (name), skipping!")
 			continue
 		}
-		if _, ok := dses[tc.DeliveryServiceName(*ds.XMLID)]; !ok {
+		if _, ok := dses[tc.DeliveryServiceName(ds.XMLID)]; !ok {
 			continue // skip: this ds isn't assigned to this server, this is normal
 		}
 		if ds.SigningAlgorithm == nil || *ds.SigningAlgorithm != tc.SigningAlgorithmURISigning {
 			continue // not signed, so not in our list of signed dses to make config files for.
 		}
-		uriSignedDSes = append(uriSignedDSes, tc.DeliveryServiceName(*ds.XMLID))
+		uriSignedDSes = append(uriSignedDSes, tc.DeliveryServiceName(ds.XMLID))
 	}
 
 	return uriSignedDSes, warnings
@@ -328,6 +334,9 @@ func filterConfigFileDSes(server *Server, deliveryServices []DeliveryService, de
 				warnings = append(warnings, "got delivery service with no ID, skipping!")
 				continue
 			}
+			if ds.Active == tc.DSActiveStateInactive {
+				continue
+			}
 			dsIDs[*ds.ID] = struct{}{}
 		}
 
@@ -336,7 +345,7 @@ func filterConfigFileDSes(server *Server, deliveryServices []DeliveryService, de
 
 		dssMap := map[int]struct{}{}
 		for _, dss := range deliveryServiceServers {
-			if dss.Server != *server.ID {
+			if dss.Server != server.ID {
 				continue
 			}
 			if _, ok := dsIDs[dss.DeliveryService]; !ok {
@@ -350,14 +359,14 @@ func filterConfigFileDSes(server *Server, deliveryServices []DeliveryService, de
 				warnings = append(warnings, "got deliveryservice with nil id, skipping!")
 				continue
 			}
-			if ds.XMLID == nil {
+			if ds.XMLID == "" {
 				warnings = append(warnings, "got deliveryservice with nil xmlId (name), skipping!")
 				continue
 			}
 			if _, ok := dssMap[*ds.ID]; !ok && ds.Topology == nil {
 				continue
 			}
-			dses[tc.DeliveryServiceName(*ds.XMLID)] = ds
+			dses[tc.DeliveryServiceName(ds.XMLID)] = ds
 		}
 	} else {
 		for _, ds := range deliveryServices {
@@ -365,14 +374,17 @@ func filterConfigFileDSes(server *Server, deliveryServices []DeliveryService, de
 				warnings = append(warnings, "got deliveryservice with nil id, skipping!")
 				continue
 			}
-			if ds.XMLID == nil {
+			if ds.XMLID == "" {
 				warnings = append(warnings, "got deliveryservice with nil xmlId (name), skipping!")
 				continue
 			}
-			if ds.CDNID == nil || *ds.CDNID != *server.CDNID {
+			if ds.CDNID != server.CDNID {
 				continue
 			}
-			dses[tc.DeliveryServiceName(*ds.XMLID)] = ds
+			if ds.Active == tc.DSActiveStateInactive {
+				continue
+			}
+			dses[tc.DeliveryServiceName(ds.XMLID)] = ds
 		}
 	}
 	return dses, warnings
@@ -395,7 +407,7 @@ func getTOURLAndReverseProxy(globalParams []tc.Parameter) (string, string) {
 	return toURL, toReverseProxyURL
 }
 
-func getLocationParams(serverParams []tc.Parameter) map[string]configProfileParams {
+func getLocationParams(serverParams []tc.ParameterV5) map[string]configProfileParams {
 	locationParams := map[string]configProfileParams{}
 	for _, param := range serverParams {
 		if param.Name == "location" {
@@ -413,8 +425,8 @@ type configProfileParams struct {
 	Path string
 }
 
-func requiredFiles(atsMajorVer int) []string {
-	if atsMajorVer >= 9 {
+func requiredFiles(atsMajorVersion uint) []string {
+	if atsMajorVersion >= 9 {
 		return requiredFiles9()
 	}
 	return requiredFiles8()
