@@ -436,45 +436,3 @@ func TestUserV4_Downgrade(t *testing.T) {
 		t.Errorf("Incorrect Username after downgrade; want: '%s', got: '%s'", username, *downgraded.Username)
 	}
 }
-
-func TestCopyUtilities(t *testing.T) {
-	var s *string
-	copiedS := copyStringIfNotNil(s)
-	if copiedS != nil {
-		t.Errorf("Copying a nil string should've given nil, got: %s", *copiedS)
-	}
-	s = new(string)
-	*s = "test string"
-	copiedS = copyStringIfNotNil(s)
-	if copiedS == nil {
-		t.Errorf("Copied pointer to '%s' was nil", *s)
-	} else {
-		if *copiedS != *s {
-			t.Errorf("Incorrectly copied string pointer; expected: '%s', got: '%s'", *s, *copiedS)
-		}
-		*s = "a different test string"
-		if *copiedS == *s {
-			t.Error("Expected copy to be 'deep' but modifying the original string changed the copy")
-		}
-	}
-
-	var i *int
-	copiedI := copyIntIfNotNil(i)
-	if copiedI != nil {
-		t.Errorf("Copying a nil int should've given nil, got: %d", *copiedI)
-	}
-	i = new(int)
-	*i = 9000
-	copiedI = copyIntIfNotNil(i)
-	if copiedI == nil {
-		t.Errorf("Copied pointer to %d was nil", *i)
-	} else {
-		if *copiedI != *i {
-			t.Errorf("Incorrectly copied int pointer; expected: %d, got: %d", *i, *copiedI)
-		}
-		*i = 9001
-		if *copiedI == *i {
-			t.Error("Expected copy to be 'deep' but modifying the original int changed the copy")
-		}
-	}
-}
