@@ -19,18 +19,23 @@ import (
 	"encoding/json"
 	"net/http"
 	"net/url"
+	"strconv"
 	"testing"
+	"time"
 
-	"github.com/apache/trafficcontrol/lib/go-tc"
-	"github.com/apache/trafficcontrol/traffic_ops/testing/api/assert"
-	"github.com/apache/trafficcontrol/traffic_ops/testing/api/utils"
-	"github.com/apache/trafficcontrol/traffic_ops/toclientlib"
-	client "github.com/apache/trafficcontrol/traffic_ops/v4-client"
+	"github.com/apache/trafficcontrol/v8/lib/go-tc"
+	totest "github.com/apache/trafficcontrol/v8/lib/go-tc/totestv4"
+	"github.com/apache/trafficcontrol/v8/lib/go-util"
+	"github.com/apache/trafficcontrol/v8/lib/go-util/assert"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/testing/api/utils"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/toclientlib"
+	client "github.com/apache/trafficcontrol/v8/traffic_ops/v4-client"
 )
 
 func TestCDNLocks(t *testing.T) {
-	WithObjs(t, []TCObj{Types, CacheGroups, CDNs, Parameters, Profiles, Statuses, Divisions, Regions, PhysLocations, Servers, ServiceCategories, Topologies, Tenants, Roles, Users, DeliveryServices, StaticDNSEntries, CDNLocks}, func() {
+	WithObjs(t, []TCObj{Types, CacheGroups, CDNs, Parameters, Profiles, ProfileParameters, Statuses, Divisions, Regions, PhysLocations, Servers, ServiceCategories, Topologies, Tenants, Roles, Users, DeliveryServices, StaticDNSEntries, CDNLocks}, func() {
 
+		now := time.Now().Round(time.Microsecond)
 		opsUserSession := utils.CreateV4Session(t, Config.TrafficOps.URL, "opsuser", "pa$$word", Config.Default.Session.TimeoutInSecs)
 		opsUserWithLockSession := utils.CreateV4Session(t, Config.TrafficOps.URL, "opslockuser", "pa$$word", Config.Default.Session.TimeoutInSecs)
 
@@ -106,21 +111,41 @@ func TestCDNLocks(t *testing.T) {
 			},
 			"SERVERS QUEUE UPDATES": {
 				"OK when USER OWNS LOCK": {
-					EndpointId: GetServerID(t, "cdn2-test-edge"), ClientSession: opsUserWithLockSession,
+					EndpointID: totest.GetServerID(t, TOSession, "cdn2-test-edge"), ClientSession: opsUserWithLockSession,
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId: GetServerID(t, "cdn2-test-edge"), ClientSession: TOSession,
+					EndpointID: totest.GetServerID(t, TOSession, "cdn2-test-edge"), ClientSession: TOSession,
 					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
 			},
+			"SERVERS HOSTNAME UPDATE": {
+				"CONFIG_APPLY_TIME is SET EVEN when CDN LOCKED": {
+					ClientSession: opsUserWithLockSession,
+					RequestOpts:   client.RequestOptions{QueryParameters: url.Values{"hostName": {"cdn2-test-edge"}}},
+					RequestBody: map[string]interface{}{
+						"config_apply_time": util.TimePtr(now),
+					},
+					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK),
+						validateServerApplyTimes("cdn2-test-edge", map[string]interface{}{"ConfigApplyTime": now})),
+				},
+				"REVALIDATE_APPLY_TIME is SET EVEN when CDN LOCKED": {
+					ClientSession: opsUserWithLockSession,
+					RequestOpts:   client.RequestOptions{QueryParameters: url.Values{"hostName": {"cdn2-test-edge"}}},
+					RequestBody: map[string]interface{}{
+						"revalidate_apply_time": util.TimePtr(now),
+					},
+					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK),
+						validateServerApplyTimes("cdn2-test-edge", map[string]interface{}{"RevalApplyTime": now})),
+				},
+			},
 			"TOPOLOGY QUEUE UPDATES": {
 				"OK when USER OWNS LOCK": {
 					ClientSession: opsUserWithLockSession,
 					RequestOpts:   client.RequestOptions{QueryParameters: url.Values{"topology": {"top-for-ds-req"}}},
 					RequestBody: map[string]interface{}{
 						"action": "queue",
-						"cdnId":  GetCDNID(t, "cdn2")(),
+						"cdnId":  totest.GetCDNID(t, TOSession, "cdn2")(),
 					},
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
@@ -129,7 +154,7 @@ func TestCDNLocks(t *testing.T) {
 					RequestOpts:   client.RequestOptions{QueryParameters: url.Values{"topology": {"top-for-ds-req"}}},
 					RequestBody: map[string]interface{}{
 						"action": "queue",
-						"cdnId":  GetCDNID(t, "cdn2")(),
+						"cdnId":  totest.GetCDNID(t, TOSession, "cdn2")(),
 					},
 					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
@@ -138,14 +163,14 @@ func TestCDNLocks(t *testing.T) {
 					RequestOpts:   client.RequestOptions{QueryParameters: url.Values{"topology": {"top-for-ds-req"}}},
 					RequestBody: map[string]interface{}{
 						"action": "dequeue",
-						"cdnId":  GetCDNID(t, "cdn2")(),
+						"cdnId":  totest.GetCDNID(t, TOSession, "cdn2")(),
 					},
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 			},
 			"CDN UPDATE": {
 				"OK when USER OWNS LOCK": {
-					EndpointId: GetCDNID(t, "cdn2"), ClientSession: opsUserWithLockSession,
+					EndpointID: totest.GetCDNID(t, TOSession, "cdn2"), ClientSession: opsUserWithLockSession,
 					RequestBody: map[string]interface{}{
 						"dnssecEnabled": false,
 						"domainName":    "newdomain",
@@ -154,7 +179,7 @@ func TestCDNLocks(t *testing.T) {
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId: GetCDNID(t, "cdn2"), ClientSession: TOSession,
+					EndpointID: totest.GetCDNID(t, TOSession, "cdn2"), ClientSession: TOSession,
 					RequestBody: map[string]interface{}{
 						"dnssecEnabled": false,
 						"domainName":    "newdomaintest",
@@ -165,32 +190,32 @@ func TestCDNLocks(t *testing.T) {
 			},
 			"CDN DELETE": {
 				"OK when USER OWNS LOCK": {
-					EndpointId: GetCDNID(t, "cdndelete"), ClientSession: opsUserWithLockSession,
+					EndpointID: totest.GetCDNID(t, TOSession, "cdndelete"), ClientSession: opsUserWithLockSession,
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId: GetCDNID(t, "cdn2"), ClientSession: TOSession,
+					EndpointID: totest.GetCDNID(t, TOSession, "cdn2"), ClientSession: TOSession,
 					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
 			},
 			"CACHE GROUP UPDATE": {
 				"OK when USER OWNS LOCK": {
-					EndpointId: GetCacheGroupId(t, "cachegroup1"), ClientSession: opsUserWithLockSession,
+					EndpointID: totest.GetCacheGroupId(t, TOSession, "cachegroup1"), ClientSession: opsUserWithLockSession,
 					RequestBody: map[string]interface{}{
 						"name":      "cachegroup1",
 						"shortName": "newShortName",
 						"typeName":  "EDGE_LOC",
-						"typeId":    -1,
+						"typeId":    totest.GetTypeId(t, TOSession, "EDGE_LOC"),
 					},
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId: GetCacheGroupId(t, "cachegroup1"), ClientSession: TOSession,
+					EndpointID: totest.GetCacheGroupId(t, TOSession, "cachegroup1"), ClientSession: TOSession,
 					RequestBody: map[string]interface{}{
 						"name":      "cachegroup1",
 						"shortName": "newShortName",
 						"typeName":  "EDGE_LOC",
-						"typeId":    -1,
+						"typeId":    totest.GetTypeId(t, TOSession, "EDGE_LOC"),
 					},
 					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
@@ -202,30 +227,132 @@ func TestCDNLocks(t *testing.T) {
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
 					ClientSession: TOSession, RequestBody: generateDeliveryService(t, map[string]interface{}{
-						"xmlId": "testDSLock2", "cdnId": GetCDNID(t, "cdn2")()}),
+						"xmlId": "testDSLock2", "cdnId": totest.GetCDNID(t, TOSession, "cdn2")()}),
 					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
 			},
 			"DELIVERY SERVICE PUT": {
 				"OK when USER OWNS LOCK": {
-					EndpointId: GetDeliveryServiceId(t, "basic-ds-in-cdn2"), ClientSession: opsUserWithLockSession,
+					EndpointID: totest.GetDeliveryServiceId(t, TOSession, "basic-ds-in-cdn2"), ClientSession: opsUserWithLockSession,
 					RequestBody: generateDeliveryService(t, map[string]interface{}{
-						"xmlId": "basic-ds-in-cdn2", "cdnId": GetCDNID(t, "cdn2")(), "cdnName": "cdn2", "routingName": "cdn"}),
+						"xmlId": "basic-ds-in-cdn2", "cdnId": totest.GetCDNID(t, TOSession, "cdn2")(), "cdnName": "cdn2", "routingName": "cdn"}),
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId: GetDeliveryServiceId(t, "basic-ds-in-cdn2"), ClientSession: TOSession,
+					EndpointID: totest.GetDeliveryServiceId(t, TOSession, "basic-ds-in-cdn2"), ClientSession: TOSession,
 					RequestBody:  generateDeliveryService(t, map[string]interface{}{}),
 					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
 			},
 			"DELIVERY SERVICE DELETE": {
 				"OK when USER OWNS LOCK": {
-					EndpointId: GetDeliveryServiceId(t, "ds-forked-topology"), ClientSession: opsUserWithLockSession,
+					EndpointID: totest.GetDeliveryServiceId(t, TOSession, "ds-forked-topology"), ClientSession: opsUserWithLockSession,
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId: GetDeliveryServiceId(t, "top-ds-in-cdn2"), ClientSession: TOSession,
+					EndpointID: totest.GetDeliveryServiceId(t, TOSession, "top-ds-in-cdn2"), ClientSession: TOSession,
+					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
+				},
+			},
+			"PROFILE POST": {
+				"OK when USER OWNS LOCK": {
+					ClientSession: opsUserWithLockSession,
+					RequestBody: map[string]interface{}{
+						"cdn":              totest.GetCDNID(t, TOSession, "cdn2")(),
+						"cdnName":          "cdn2",
+						"description":      "test cdn locks description",
+						"name":             "TestLocks",
+						"routing_disabled": false,
+						"type":             "ATS_PROFILE",
+					},
+					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
+				},
+				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
+					ClientSession: TOSession,
+					RequestBody: map[string]interface{}{
+						"cdn":              totest.GetCDNID(t, TOSession, "cdn2")(),
+						"cdnName":          "cdn2",
+						"description":      "test cdn locks description",
+						"name":             "TestLocksForbidden",
+						"routing_disabled": false,
+						"type":             "ATS_PROFILE",
+					},
+					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
+				},
+			},
+			"PROFILE PUT": {
+				"OK when USER OWNS LOCK": {
+					EndpointID:    totest.GetProfileID(t, TOSession, "CDN2_EDGE"),
+					ClientSession: opsUserWithLockSession,
+					RequestBody: map[string]interface{}{
+						"cdn":              totest.GetCDNID(t, TOSession, "cdn2")(),
+						"cdnName":          "cdn2",
+						"description":      "cdn2 edge description updated when user owns lock",
+						"name":             "CDN2_EDGE",
+						"routing_disabled": false,
+						"type":             "ATS_PROFILE",
+					},
+					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
+				},
+				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
+					EndpointID:    totest.GetProfileID(t, TOSession, "EDGEInCDN2"),
+					ClientSession: TOSession,
+					RequestBody: map[string]interface{}{
+						"cdn":              totest.GetCDNID(t, TOSession, "cdn2")(),
+						"cdnName":          "cdn2",
+						"description":      "should fail",
+						"name":             "EDGEInCDN2",
+						"routing_disabled": false,
+						"type":             "ATS_PROFILE",
+					},
+					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
+				},
+			},
+			"PROFILE DELETE": {
+				"OK when USER OWNS LOCK": {
+					EndpointID:    totest.GetProfileID(t, TOSession, "CCR2"),
+					ClientSession: opsUserWithLockSession,
+					Expectations:  utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
+				},
+				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
+					EndpointID:    totest.GetProfileID(t, TOSession, "MID2"),
+					ClientSession: TOSession,
+					Expectations:  utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
+				},
+			},
+			"PROFILE PARAMETER POST": {
+				"OK when USER OWNS LOCK": {
+					ClientSession: opsUserWithLockSession,
+					RequestBody: map[string]interface{}{
+						"profileId":   totest.GetProfileID(t, TOSession, "EDGEInCDN2")(),
+						"parameterId": GetParameterID(t, "CONFIG proxy.config.admin.user_id", "records.config", "STRING ats")(),
+					},
+					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
+				},
+				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
+					ClientSession: TOSession,
+					RequestBody: map[string]interface{}{
+						"profileId":   totest.GetProfileID(t, TOSession, "EDGEInCDN2")(),
+						"parameterId": GetParameterID(t, "CONFIG proxy.config.admin.user_id", "records.config", "STRING ats")(),
+					},
+					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
+				},
+			},
+			"PROFILE PARAMETER DELETE": {
+				"OK when USER OWNS LOCK": {
+					EndpointID:    totest.GetProfileID(t, TOSession, "OKwhenUserOwnLocks"),
+					ClientSession: opsUserWithLockSession,
+					RequestOpts: client.RequestOptions{QueryParameters: url.Values{
+						"parameterId": {strconv.Itoa(GetParameterID(t, "test.cdnlock.delete", "rascal.properties", "25.0")())},
+					}},
+					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
+				},
+				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
+					EndpointID:    totest.GetProfileID(t, TOSession, "FORBIDDENwhenDoesntOwnLock"),
+					ClientSession: TOSession,
+					RequestOpts: client.RequestOptions{QueryParameters: url.Values{
+						"parameterId": {strconv.Itoa(GetParameterID(t, "test.cdnlock.forbidden.delete", "rascal.properties", "25.0")())},
+					}},
 					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
 			},
@@ -233,7 +360,7 @@ func TestCDNLocks(t *testing.T) {
 				"OK when USER OWNS LOCK": {
 					ClientSession: opsUserWithLockSession,
 					RequestBody: generateServer(t, map[string]interface{}{
-						"cdnId":        GetCDNID(t, "cdn2")(),
+						"cdnId":        totest.GetCDNID(t, TOSession, "cdn2")(),
 						"profileNames": []string{"EDGEInCDN2"},
 					}),
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusCreated)),
@@ -241,7 +368,7 @@ func TestCDNLocks(t *testing.T) {
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
 					ClientSession: TOSession,
 					RequestBody: generateServer(t, map[string]interface{}{
-						"cdnId":        GetCDNID(t, "cdn2")(),
+						"cdnId":        totest.GetCDNID(t, TOSession, "cdn2")(),
 						"profileNames": []string{"EDGEInCDN2"},
 						"interfaces": []map[string]interface{}{{
 							"ipAddresses": []map[string]interface{}{{
@@ -256,11 +383,11 @@ func TestCDNLocks(t *testing.T) {
 			},
 			"SERVER PUT": {
 				"OK when USER OWNS LOCK": {
-					EndpointId:    GetServerID(t, "edge1-cdn2"),
+					EndpointID:    totest.GetServerID(t, TOSession, "edge1-cdn2"),
 					ClientSession: opsUserWithLockSession,
-					RequestBody: generateServer(t, generateServer(t, map[string]interface{}{
-						"id":           GetServerID(t, "edge1-cdn2")(),
-						"cdnId":        GetCDNID(t, "cdn2")(),
+					RequestBody: generateServer(t, map[string]interface{}{
+						"id":           totest.GetServerID(t, TOSession, "edge1-cdn2")(),
+						"cdnId":        totest.GetCDNID(t, TOSession, "cdn2")(),
 						"profileNames": []string{"EDGEInCDN2"},
 						"interfaces": []map[string]interface{}{{
 							"ipAddresses": []map[string]interface{}{{
@@ -269,16 +396,16 @@ func TestCDNLocks(t *testing.T) {
 							}},
 							"name": "eth0",
 						}},
-					})),
+					}),
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId:    GetServerID(t, "dtrc-edge-07"),
+					EndpointID:    totest.GetServerID(t, TOSession, "dtrc-edge-07"),
 					ClientSession: TOSession,
-					RequestBody: generateServer(t, generateServer(t, map[string]interface{}{
-						"id":           GetServerID(t, "dtrc-edge-07")(),
-						"cdnId":        GetCDNID(t, "cdn2")(),
-						"cachegroupId": GetCacheGroupId(t, "dtrc2")(),
+					RequestBody: generateServer(t, map[string]interface{}{
+						"id":           totest.GetServerID(t, TOSession, "dtrc-edge-07")(),
+						"cdnId":        totest.GetCDNID(t, TOSession, "cdn2")(),
+						"cachegroupId": totest.GetCacheGroupId(t, TOSession, "dtrc2")(),
 						"profileNames": []string{"CDN2_EDGE"},
 						"interfaces": []map[string]interface{}{{
 							"ipAddresses": []map[string]interface{}{{
@@ -287,18 +414,18 @@ func TestCDNLocks(t *testing.T) {
 							}},
 							"name": "eth0",
 						}},
-					})),
+					}),
 					Expectations: utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
 			},
 			"SERVER DELETE": {
 				"OK when USER OWNS LOCK": {
-					EndpointId:    GetServerID(t, "atlanta-mid-17"),
+					EndpointID:    totest.GetServerID(t, TOSession, "atlanta-mid-17"),
 					ClientSession: opsUserWithLockSession,
 					Expectations:  utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId:    GetServerID(t, "denver-mso-org-02"),
+					EndpointID:    totest.GetServerID(t, TOSession, "denver-mso-org-02"),
 					ClientSession: TOSession,
 					Expectations:  utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
@@ -329,7 +456,7 @@ func TestCDNLocks(t *testing.T) {
 			},
 			"STATIC DNS ENTRIES PUT": {
 				"OK when USER OWNS LOCK": {
-					EndpointId:    GetStaticDNSEntryID(t, "host2"),
+					EndpointID:    GetStaticDNSEntryID(t, "host2"),
 					ClientSession: opsUserWithLockSession,
 					RequestBody: map[string]interface{}{
 						"address":         "192.168.0.2",
@@ -341,7 +468,7 @@ func TestCDNLocks(t *testing.T) {
 					Expectations: utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId:    GetStaticDNSEntryID(t, "cdnlock-test-delete-host"),
+					EndpointID:    GetStaticDNSEntryID(t, "cdnlock-test-delete-host"),
 					ClientSession: TOSession,
 					RequestBody: map[string]interface{}{
 						"address":         "192.168.0.2",
@@ -355,12 +482,12 @@ func TestCDNLocks(t *testing.T) {
 			},
 			"STATIC DNS ENTRIES DELETE": {
 				"OK when USER OWNS LOCK": {
-					EndpointId:    GetStaticDNSEntryID(t, "host3"),
+					EndpointID:    GetStaticDNSEntryID(t, "host3"),
 					ClientSession: opsUserWithLockSession,
 					Expectations:  utils.CkRequest(utils.NoError(), utils.HasStatus(http.StatusOK)),
 				},
 				"FORBIDDEN when ADMIN USER DOESNT OWN LOCK": {
-					EndpointId:    GetStaticDNSEntryID(t, "cdnlock-negtest-delete-host"),
+					EndpointID:    GetStaticDNSEntryID(t, "cdnlock-negtest-delete-host"),
 					ClientSession: TOSession,
 					Expectations:  utils.CkRequest(utils.HasError(), utils.HasStatus(http.StatusForbidden)),
 				},
@@ -370,219 +497,218 @@ func TestCDNLocks(t *testing.T) {
 		for method, testCases := range methodTests {
 			t.Run(method, func(t *testing.T) {
 				for name, testCase := range testCases {
-
-					topology := ""
-					cdn := tc.CDN{}
-					cdnLock := tc.CDNLock{}
-					cacheGroup := tc.CacheGroupNullable{}
-					ds := tc.DeliveryServiceV4{}
-					server := tc.ServerV4{}
-					topQueueUp := tc.TopologiesQueueUpdateRequest{}
-					staticDNSEntry := tc.StaticDNSEntry{}
-
-					if testCase.RequestOpts.QueryParameters.Has("topology") {
-						topology = testCase.RequestOpts.QueryParameters.Get("topology")
-					}
+					var dat []byte
+					var err error
 
 					if testCase.RequestBody != nil {
-						if _, ok := testCase.RequestBody["xmlId"]; ok {
-							dat, err := json.Marshal(testCase.RequestBody)
-							assert.NoError(t, err, "Error occurred when marshalling request body: %v", err)
-							err = json.Unmarshal(dat, &ds)
-							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
-						} else if _, ok := testCase.RequestBody["hostName"]; ok {
-							dat, err := json.Marshal(testCase.RequestBody)
-							assert.NoError(t, err, "Error occurred when marshalling request body: %v", err)
-							err = json.Unmarshal(dat, &server)
-							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
-						} else if getId, ok := testCase.RequestBody["cdnId"]; ok {
-							testCase.RequestBody["cdnId"] = getId.(int)
-							dat, err := json.Marshal(testCase.RequestBody)
-							assert.NoError(t, err, "Error occurred when marshalling request body: %v", err)
-							err = json.Unmarshal(dat, &topQueueUp)
-							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
-						} else if typeName, ok := testCase.RequestBody["typeName"]; ok {
-							testCase.RequestBody["typeId"] = GetTypeId(t, typeName.(string))
-							dat, err := json.Marshal(testCase.RequestBody)
-							assert.NoError(t, err, "Error occurred when marshalling request body: %v", err)
-							err = json.Unmarshal(dat, &cacheGroup)
-							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
-						} else if _, ok := testCase.RequestBody["dnssecEnabled"]; ok {
-							dat, err := json.Marshal(testCase.RequestBody)
-							assert.NoError(t, err, "Error occurred when marshalling request body: %v", err)
-							err = json.Unmarshal(dat, &cdn)
-							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
-						} else if _, ok := testCase.RequestBody["host"]; ok {
-							dat, err := json.Marshal(testCase.RequestBody)
-							assert.NoError(t, err, "Error occurred when marshalling request body: %v", err)
-							err = json.Unmarshal(dat, &staticDNSEntry)
-							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
-						} else {
-							dat, err := json.Marshal(testCase.RequestBody)
-							assert.NoError(t, err, "Error occurred when marshalling request body: %v", err)
-							err = json.Unmarshal(dat, &cdnLock)
-							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
-						}
+						dat, err = json.Marshal(testCase.RequestBody)
+						assert.NoError(t, err, "Error occurred when marshalling request body: %v", err)
 					}
 
-					switch method {
-					case "GET":
-						t.Run(name, func(t *testing.T) {
+					cases := map[string]func(*testing.T){
+						"GET": func(t *testing.T) {
 							resp, reqInf, err := testCase.ClientSession.GetCDNLocks(testCase.RequestOpts)
 							for _, check := range testCase.Expectations {
 								check(t, reqInf, resp.Response, resp.Alerts, err)
 							}
-						})
-					case "POST":
-						t.Run(name, func(t *testing.T) {
+						},
+						"POST": func(t *testing.T) {
+							cdnLock := tc.CDNLock{}
+							err = json.Unmarshal(dat, &cdnLock)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
 							resp, reqInf, err := testCase.ClientSession.CreateCDNLock(cdnLock, testCase.RequestOpts)
 							for _, check := range testCase.Expectations {
 								check(t, reqInf, resp.Response, resp.Alerts, err)
 							}
-						})
-					case "DELETE":
-						t.Run(name, func(t *testing.T) {
+						},
+						"DELETE": func(t *testing.T) {
 							resp, reqInf, err := testCase.ClientSession.DeleteCDNLocks(testCase.RequestOpts)
 							for _, check := range testCase.Expectations {
 								check(t, reqInf, resp.Response, resp.Alerts, err)
 							}
-						})
-					case "SNAPSHOT":
-						{
-							t.Run(name, func(t *testing.T) {
-								resp, reqInf, err := testCase.ClientSession.SnapshotCRConfig(testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, resp.Response, resp.Alerts, err)
-								}
-							})
-						}
-					case "SERVERS QUEUE UPDATES":
-						{
-							t.Run(name, func(t *testing.T) {
-								resp, reqInf, err := testCase.ClientSession.SetServerQueueUpdate(testCase.EndpointId(), true, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, resp.Response, resp.Alerts, err)
-								}
-							})
-						}
-					case "TOPOLOGY QUEUE UPDATES":
-						{
-							t.Run(name, func(t *testing.T) {
-								resp, reqInf, err := testCase.ClientSession.TopologiesQueueUpdate(topology, topQueueUp, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, resp.Alerts, err)
-								}
-							})
-						}
-					case "CACHE GROUP UPDATE":
-						{
-							t.Run(name, func(t *testing.T) {
-								resp, reqInf, err := testCase.ClientSession.UpdateCacheGroup(testCase.EndpointId(), cacheGroup, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, resp.Alerts, err)
-								}
-							})
-						}
-					case "CDN UPDATE":
-						{
-							t.Run(name, func(t *testing.T) {
-								alerts, reqInf, err := testCase.ClientSession.UpdateCDN(testCase.EndpointId(), cdn, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, alerts, err)
-								}
-							})
-						}
-					case "CDN DELETE":
-						{
-							t.Run(name, func(t *testing.T) {
-								alerts, reqInf, err := testCase.ClientSession.DeleteCDN(testCase.EndpointId(), testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, alerts, err)
-								}
-							})
-						}
-					case "DELIVERY SERVICE POST":
-						{
-							t.Run(name, func(t *testing.T) {
-								resp, reqInf, err := testCase.ClientSession.CreateDeliveryService(ds, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, resp.Alerts, err)
-								}
-							})
-						}
-					case "DELIVERY SERVICE PUT":
-						{
-							t.Run(name, func(t *testing.T) {
-								resp, reqInf, err := testCase.ClientSession.UpdateDeliveryService(testCase.EndpointId(), ds, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, resp.Alerts, err)
-								}
-							})
-						}
-					case "DELIVERY SERVICE DELETE":
-						{
-							t.Run(name, func(t *testing.T) {
-								resp, reqInf, err := testCase.ClientSession.DeleteDeliveryService(testCase.EndpointId(), testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, resp.Alerts, err)
-								}
-							})
-						}
-					case "SERVER POST":
-						{
-							t.Run(name, func(t *testing.T) {
-								alerts, reqInf, err := testCase.ClientSession.CreateServer(server, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, alerts, err)
-								}
-							})
-						}
-					case "SERVER PUT":
-						{
-							t.Run(name, func(t *testing.T) {
-								alerts, reqInf, err := testCase.ClientSession.UpdateServer(testCase.EndpointId(), server, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, alerts, err)
-								}
-							})
-						}
-					case "SERVER DELETE":
-						{
-							t.Run(name, func(t *testing.T) {
-								alerts, reqInf, err := testCase.ClientSession.DeleteServer(testCase.EndpointId(), testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, alerts, err)
-								}
-							})
-						}
-					case "STATIC DNS ENTRIES POST":
-						{
-							t.Run(name, func(t *testing.T) {
-								alerts, reqInf, err := testCase.ClientSession.CreateStaticDNSEntry(staticDNSEntry, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, alerts, err)
-								}
-							})
-						}
-					case "STATIC DNS ENTRIES PUT":
-						{
-							t.Run(name, func(t *testing.T) {
-								alerts, reqInf, err := testCase.ClientSession.UpdateStaticDNSEntry(testCase.EndpointId(), staticDNSEntry, testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, alerts, err)
-								}
-							})
-						}
-					case "STATIC DNS ENTRIES DELETE":
-						{
-							t.Run(name, func(t *testing.T) {
-								alerts, reqInf, err := testCase.ClientSession.DeleteStaticDNSEntry(testCase.EndpointId(), testCase.RequestOpts)
-								for _, check := range testCase.Expectations {
-									check(t, reqInf, nil, alerts, err)
-								}
-							})
-						}
-					default:
+						},
+						"SNAPSHOT": func(t *testing.T) {
+							resp, reqInf, err := testCase.ClientSession.SnapshotCRConfig(testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, resp.Response, resp.Alerts, err)
+							}
+						},
+						"SERVERS QUEUE UPDATES": func(t *testing.T) {
+							resp, reqInf, err := testCase.ClientSession.SetServerQueueUpdate(testCase.EndpointID(), true, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, resp.Response, resp.Alerts, err)
+							}
+						},
+						"SERVERS HOSTNAME UPDATE": func(t *testing.T) {
+							var hostName string
+							var configApplyTime *time.Time
+							var revalApplyTime *time.Time
+
+							if hostNameParam, ok := testCase.RequestOpts.QueryParameters["hostName"]; ok {
+								hostName = hostNameParam[0]
+							}
+							if configApplyTimeVal, ok := testCase.RequestBody["config_apply_time"]; ok {
+								configApplyTime = configApplyTimeVal.(*time.Time)
+							}
+							if revalApplyTimeVal, ok := testCase.RequestBody["revalidate_apply_time"]; ok {
+								revalApplyTime = revalApplyTimeVal.(*time.Time)
+							}
+							alerts, reqInf, err := testCase.ClientSession.SetUpdateServerStatusTimes(hostName, configApplyTime, revalApplyTime, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"TOPOLOGY QUEUE UPDATES": func(t *testing.T) {
+							topology := testCase.RequestOpts.QueryParameters.Get("topology")
+							topQueueUp := tc.TopologiesQueueUpdateRequest{}
+							err = json.Unmarshal(dat, &topQueueUp)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							resp, reqInf, err := testCase.ClientSession.TopologiesQueueUpdate(topology, topQueueUp, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, resp.Alerts, err)
+							}
+						},
+						"CACHE GROUP UPDATE": func(t *testing.T) {
+							cacheGroup := tc.CacheGroupNullable{}
+							err = json.Unmarshal(dat, &cacheGroup)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							resp, reqInf, err := testCase.ClientSession.UpdateCacheGroup(testCase.EndpointID(), cacheGroup, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, resp.Alerts, err)
+							}
+						},
+						"CDN UPDATE": func(t *testing.T) {
+							cdn := tc.CDN{}
+							err = json.Unmarshal(dat, &cdn)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							alerts, reqInf, err := testCase.ClientSession.UpdateCDN(testCase.EndpointID(), cdn, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"CDN DELETE": func(t *testing.T) {
+							alerts, reqInf, err := testCase.ClientSession.DeleteCDN(testCase.EndpointID(), testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"DELIVERY SERVICE POST": func(t *testing.T) {
+							ds := tc.DeliveryServiceV4{}
+							err = json.Unmarshal(dat, &ds)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							resp, reqInf, err := testCase.ClientSession.CreateDeliveryService(ds, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, resp.Alerts, err)
+							}
+						},
+						"DELIVERY SERVICE PUT": func(t *testing.T) {
+							ds := tc.DeliveryServiceV4{}
+							err = json.Unmarshal(dat, &ds)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							resp, reqInf, err := testCase.ClientSession.UpdateDeliveryService(testCase.EndpointID(), ds, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, resp.Alerts, err)
+							}
+						},
+						"DELIVERY SERVICE DELETE": func(t *testing.T) {
+							resp, reqInf, err := testCase.ClientSession.DeleteDeliveryService(testCase.EndpointID(), testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, resp.Alerts, err)
+							}
+						},
+						"PROFILE POST": func(t *testing.T) {
+							profile := tc.Profile{}
+							err = json.Unmarshal(dat, &profile)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							alerts, reqInf, err := testCase.ClientSession.CreateProfile(profile, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"PROFILE PUT": func(t *testing.T) {
+							profile := tc.Profile{}
+							err = json.Unmarshal(dat, &profile)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							alerts, reqInf, err := testCase.ClientSession.UpdateProfile(testCase.EndpointID(), profile, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"PROFILE DELETE": func(t *testing.T) {
+							alerts, reqInf, err := testCase.ClientSession.DeleteProfile(testCase.EndpointID(), testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"PROFILE PARAMETER POST": func(t *testing.T) {
+							profileParameter := tc.ProfileParameterCreationRequest{}
+							err = json.Unmarshal(dat, &profileParameter)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							alerts, reqInf, err := testCase.ClientSession.CreateProfileParameter(profileParameter, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"PROFILE PARAMETER DELETE": func(t *testing.T) {
+							parameterId, _ := strconv.Atoi(testCase.RequestOpts.QueryParameters["parameterId"][0])
+							alerts, reqInf, err := testCase.ClientSession.DeleteProfileParameter(testCase.EndpointID(), parameterId, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"SERVER POST": func(t *testing.T) {
+							server := tc.ServerV4{}
+							err = json.Unmarshal(dat, &server)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							alerts, reqInf, err := testCase.ClientSession.CreateServer(server, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"SERVER PUT": func(t *testing.T) {
+							server := tc.ServerV4{}
+							err = json.Unmarshal(dat, &server)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							alerts, reqInf, err := testCase.ClientSession.UpdateServer(testCase.EndpointID(), server, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"SERVER DELETE": func(t *testing.T) {
+							alerts, reqInf, err := testCase.ClientSession.DeleteServer(testCase.EndpointID(), testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"STATIC DNS ENTRIES POST": func(t *testing.T) {
+							staticDNSEntry := tc.StaticDNSEntry{}
+							err = json.Unmarshal(dat, &staticDNSEntry)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							alerts, reqInf, err := testCase.ClientSession.CreateStaticDNSEntry(staticDNSEntry, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"STATIC DNS ENTRIES PUT": func(t *testing.T) {
+							staticDNSEntry := tc.StaticDNSEntry{}
+							err = json.Unmarshal(dat, &staticDNSEntry)
+							assert.NoError(t, err, "Error occurred when unmarshalling request body: %v", err)
+							alerts, reqInf, err := testCase.ClientSession.UpdateStaticDNSEntry(testCase.EndpointID(), staticDNSEntry, testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+						"STATIC DNS ENTRIES DELETE": func(t *testing.T) {
+							alerts, reqInf, err := testCase.ClientSession.DeleteStaticDNSEntry(testCase.EndpointID(), testCase.RequestOpts)
+							for _, check := range testCase.Expectations {
+								check(t, reqInf, nil, alerts, err)
+							}
+						},
+					}
+
+					if _, ok := cases[method]; ok {
+						t.Run(name, cases[method])
+					} else {
 						t.Errorf("Test Case: %s not found. Test: %s failed to run.", method, name)
 					}
 				}
