@@ -1,11 +1,5 @@
 package cdn
 
-import (
-	"testing"
-
-	"github.com/apache/trafficcontrol/lib/go-tc"
-)
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -25,6 +19,12 @@ import (
  * under the License.
  */
 
+import (
+	"testing"
+
+	"github.com/apache/trafficcontrol/v8/lib/go-tc"
+)
+
 func TestGetStatsFromServiceInterface(t *testing.T) {
 	data1 := tc.ServerStats{
 		Interfaces: nil,
