@@ -29,17 +29,17 @@ import (
 	"strings"
 	"time"
 
-	"github.com/apache/trafficcontrol/lib/go-log"
-	"github.com/apache/trafficcontrol/lib/go-rfc"
-	"github.com/apache/trafficcontrol/lib/go-tc"
-	"github.com/apache/trafficcontrol/lib/go-tc/tovalidate"
-	"github.com/apache/trafficcontrol/lib/go-util"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/api"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/auth"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/dbhelpers"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/deliveryservice"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/tenant"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/util/ims"
+	"github.com/apache/trafficcontrol/v8/lib/go-log"
+	"github.com/apache/trafficcontrol/v8/lib/go-rfc"
+	"github.com/apache/trafficcontrol/v8/lib/go-tc"
+	"github.com/apache/trafficcontrol/v8/lib/go-tc/tovalidate"
+	"github.com/apache/trafficcontrol/v8/lib/go-util"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/api"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/auth"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/dbhelpers"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/deliveryservice"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/tenant"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/util/ims"
 
 	validation "github.com/go-ozzo/ozzo-validation"
 	"github.com/jmoiron/sqlx"
@@ -60,7 +60,7 @@ func (dss TODeliveryServiceServer) GetKeyFieldsInfo() []api.KeyFieldInfo {
 	return []api.KeyFieldInfo{{Field: "deliveryservice", Func: api.GetIntKey}, {Field: "server", Func: api.GetIntKey}}
 }
 
-//Implementation of the Identifier, Validator interface functions
+// Implementation of the Identifier, Validator interface functions
 func (dss TODeliveryServiceServer) GetKeys() (map[string]interface{}, bool) {
 	if dss.DeliveryService == nil {
 		return map[string]interface{}{"deliveryservice": 0}, false
@@ -78,7 +78,7 @@ func (dss TODeliveryServiceServer) GetKeys() (map[string]interface{}, bool) {
 }
 
 func (dss *TODeliveryServiceServer) GetAuditName() string {
-	if dss.DeliveryService != nil {
+	if dss.DeliveryService != nil && dss.Server != nil {
 		return strconv.Itoa(*dss.DeliveryService) + "-" + strconv.Itoa(*dss.Server)
 	}
 	return "unknown"
@@ -170,7 +170,33 @@ func ReadDSSHandler(w http.ResponseWriter, r *http.Request) {
 	if err == nil && results == nil {
 		w.WriteHeader(http.StatusNotModified)
 	}
-	api.WriteRespRaw(w, r, results)
+	if inf.Version.GreaterThanOrEqualTo(&api.Version{
+		Major: 5,
+		Minor: 0,
+	}) {
+		var resultsV5 tc.DeliveryServiceServerResponseV5
+		resultsV5.Limit = results.Limit
+		resultsV5.Orderby = results.Orderby
+		resultsV5.Size = results.Size
+		resultsV5.Alerts = results.Alerts
+		resultsV5.Response = *upgrade(results.Response)
+		api.WriteRespRaw(w, r, resultsV5)
+	} else {
+		api.WriteRespRaw(w, r, results)
+	}
+}
+
+func upgrade(dsServers []tc.DeliveryServiceServer) *[]tc.DeliveryServiceServerV5 {
+	var err error
+	dsServersV5 := make([]tc.DeliveryServiceServerV5, len(dsServers))
+	for i, s := range dsServers {
+		dsServersV5[i].Server = s.Server
+		dsServersV5[i].DeliveryService = s.DeliveryService
+		if dsServersV5[i].LastUpdated, err = util.ConvertTimeFormat(s.LastUpdated.Time, time.RFC3339); err != nil {
+			dsServersV5[i].LastUpdated = &s.LastUpdated.Time
+		}
+	}
+	return &dsServersV5
 }
 
 func (dss *TODeliveryServiceServer) readDSS(h http.Header, tx *sqlx.Tx, user *auth.CurrentUser, params map[string]string, intParams map[string]int, dsIDs []int64, serverIDs []int64, useIMS bool) (*tc.DeliveryServiceServerResponse, error, *time.Time) {
@@ -690,7 +716,7 @@ func GetReadAssigned(w http.ResponseWriter, r *http.Request) {
 	defer inf.Close()
 
 	alerts := tc.Alerts{}
-	servers, err := read(inf.Tx, inf.IntParams["id"], inf.User)
+	servers, err := read(inf)
 	if err != nil {
 		alerts.AddNewAlert(tc.ErrorLevel, err.Error())
 		api.WriteAlerts(w, r, http.StatusInternalServerError, alerts)
@@ -725,10 +751,23 @@ func GetReadAssigned(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
+	// Based on version we load Delivery Service Server - for version 5 and above we use DSServerV5
+	if inf.Version.GreaterThanOrEqualTo(&api.Version{Major: 5, Minor: 0}) {
+
+		newServerList := make([]tc.DSServerV5, len(servers))
+
+		for i, server := range servers {
+			newServerList[i] = server.Upgrade()
+		}
+
+		api.WriteAlertsObj(w, r, http.StatusOK, alerts, newServerList)
+		return
+	}
+
 	api.WriteAlertsObj(w, r, http.StatusOK, alerts, servers)
 }
 
-func read(tx *sqlx.Tx, dsID int, user *auth.CurrentUser) ([]tc.DSServerV4, error) {
+func read(inf *api.APIInfo) ([]tc.DSServerV4, error) {
 	queryDataString :=
 		`,
 cg.name as cachegroup,
@@ -774,7 +813,8 @@ JOIN status st ON s.status = st.id
 JOIN type t ON s.type = t.id
 WHERE s.id in (select server from deliveryservice_server where deliveryservice = $1)`
 
-	idRows, err := tx.Queryx(fmt.Sprintf(queryFormatString, ""), dsID)
+	dsID := inf.IntParams["id"]
+	idRows, err := inf.Tx.Queryx(fmt.Sprintf(queryFormatString, ""), dsID)
 	if err != nil {
 		return nil, errors.New("error querying dss ids: " + err.Error())
 	}
@@ -789,12 +829,12 @@ WHERE s.id in (select server from deliveryservice_server where deliveryservice =
 		serverIDs = append(serverIDs, serverID)
 	}
 
-	serversMap, err := dbhelpers.GetServersInterfaces(serverIDs, tx.Tx)
+	serversMap, err := dbhelpers.GetServersInterfaces(serverIDs, inf.Tx.Tx)
 	if err != nil {
 		return nil, errors.New("unable to get server interfaces: " + err.Error())
 	}
 
-	rows, err := tx.Queryx(fmt.Sprintf(queryFormatString, queryDataString), dsID)
+	rows, err := inf.Tx.Queryx(fmt.Sprintf(queryFormatString, queryDataString), dsID)
 	if err != nil {
 		return nil, errors.New("error querying dss rows: " + err.Error())
 	}
@@ -844,7 +884,14 @@ WHERE s.id in (select server from deliveryservice_server where deliveryservice =
 			}
 		}
 
-		if user.PrivLevel < auth.PrivLevelAdmin {
+		canViewILOPswd := false
+		if (inf.Version.GreaterThanOrEqualTo(&api.Version{Major: 4}) && inf.Config.RoleBasedPermissions) || inf.Version.GreaterThanOrEqualTo(&api.Version{Major: 5}) {
+			canViewILOPswd = inf.User.Can(tc.PermSecureServerRead)
+		} else {
+			canViewILOPswd = inf.User.PrivLevel == auth.PrivLevelAdmin
+		}
+
+		if !canViewILOPswd {
 			s.ILOPassword = util.StrPtr("")
 		}
 		servers = append(servers, s)
@@ -868,7 +915,6 @@ func (dss *TODSSDeliveryService) Read(h http.Header, useIMS bool) ([]interface{}
 	}
 	var maxTime time.Time
 	var runSecond bool
-	returnable := []interface{}{}
 	params := dss.APIInfo().Params
 	tx := dss.APIInfo().Tx.Tx
 	user := dss.APIInfo().User
@@ -897,7 +943,33 @@ func (dss *TODSSDeliveryService) Read(h http.Header, useIMS bool) ([]interface{}
 	} else {
 		where = "WHERE "
 	}
-	where += "ds.id in (SELECT deliveryService FROM deliveryservice_server where server = :server)"
+
+	where += `
+(ds.id in (
+	SELECT deliveryService FROM deliveryservice_server WHERE server = :server
+) OR ds.id in (
+	SELECT d.id FROM deliveryservice d
+	JOIN cdn c ON d.cdn_id = c.id
+	WHERE d.topology in (
+		SELECT topology FROM topology_cachegroup
+		WHERE cachegroup = (
+			SELECT name FROM cachegroup
+			WHERE id = (
+				SELECT cachegroup FROM server WHERE id = :server
+			)))
+	AND d.cdn_id = (SELECT cdn_id FROM server WHERE id = :server)))
+AND
+(( 
+(SELECT (t.name = 'ORG') FROM type t JOIN server s ON s.type = t.id WHERE s.id = :server) 
+OR 
+(SELECT COALESCE(ARRAY_AGG(ssc.server_capability), '{}') 
+FROM server_server_capability ssc 
+WHERE ssc."server" = :server) 
+@> 
+(
+SELECT COALESCE(ds.required_capabilities, '{}')
+)))
+`
 
 	tenantIDs, err := tenant.GetUserTenantIDListTx(tx, user.TenantID)
 	if err != nil {
@@ -912,7 +984,7 @@ func (dss *TODSSDeliveryService) Read(h http.Header, useIMS bool) ([]interface{}
 		runSecond, maxTime = ims.TryIfModifiedSinceQuery(dss.APIInfo().Tx, h, queryValues, selectMaxLastUpdatedQuery(where))
 		if !runSecond {
 			log.Debugln("IMS HIT")
-			return returnable, nil, nil, http.StatusNotModified, &maxTime
+			return nil, nil, nil, http.StatusNotModified, &maxTime
 		}
 		log.Debugln("IMS MISS")
 	} else {
@@ -929,16 +1001,20 @@ func (dss *TODSSDeliveryService) Read(h http.Header, useIMS bool) ([]interface{}
 		return nil, userErr, sysErr, http.StatusInternalServerError, nil
 	}
 
-	for _, ds := range dses {
-		if version.Major > 3 && version.Minor >= 0 {
-			ds = ds.RemoveLD1AndLD2()
+	returnable := make([]interface{}, 0, len(dses))
+	for _, d := range dses {
+		ds := d.DS
+		if version.Major > 4 {
 			returnable = append(returnable, ds)
+		} else if version.Major > 3 && version.Minor >= 0 {
+			returnable = append(returnable, ds.Downgrade())
 		} else {
+			legacyDS := ds.Downgrade()
 			if version.Minor > 0 {
-				dsV31 := ds.DowngradeToV31()
+				dsV31 := legacyDS.DowngradeToV31()
 				returnable = append(returnable, dsV31)
 			} else {
-				dsV30 := ds.DowngradeToV31().DeliveryServiceV30
+				dsV30 := legacyDS.DowngradeToV31().DeliveryServiceV30
 				returnable = append(returnable, dsV30)
 			}
 		}
@@ -993,8 +1069,9 @@ FROM
 func scanDSInfoRow(row *sql.Row) (DSInfo, bool, error) {
 	di := DSInfo{}
 	var useMSO *bool
+	var active tc.DeliveryServiceActiveState
 	if err := row.Scan(
-		&di.Active,
+		&active,
 		&di.ID,
 		&di.Name,
 		&di.Type,
@@ -1013,6 +1090,7 @@ func scanDSInfoRow(row *sql.Row) (DSInfo, bool, error) {
 		}
 		return DSInfo{}, false, fmt.Errorf("querying delivery service server ds info: %v", err)
 	}
+	di.Active = active == tc.DSActiveStateActive
 	di.Type = tc.DSTypeFromString(string(di.Type))
 	if useMSO != nil {
 		di.UseMultiSiteOrigin = *useMSO
