@@ -30,14 +30,14 @@ import (
 	"strings"
 	"time"
 
-	"github.com/apache/trafficcontrol/lib/go-log"
-	"github.com/apache/trafficcontrol/lib/go-rfc"
-	"github.com/apache/trafficcontrol/lib/go-tc"
-	"github.com/apache/trafficcontrol/lib/go-util"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/api"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/dbhelpers"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/tenant"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/util/ims"
+	"github.com/apache/trafficcontrol/v8/lib/go-log"
+	"github.com/apache/trafficcontrol/v8/lib/go-rfc"
+	"github.com/apache/trafficcontrol/v8/lib/go-tc"
+	"github.com/apache/trafficcontrol/v8/lib/go-util"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/api"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/dbhelpers"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/tenant"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/util/ims"
 
 	validation "github.com/go-ozzo/ozzo-validation"
 	"github.com/go-ozzo/ozzo-validation/is"
@@ -595,6 +595,17 @@ func CreateV40(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
+	_, cdnName, _, err := dbhelpers.GetDSNameAndCDNFromID(inf.Tx.Tx, int(dsid))
+	if err != nil {
+		api.HandleErr(w, r, inf.Tx.Tx, http.StatusInternalServerError, nil, errors.New("getting delivery service and CDN name from ID: "+err.Error()))
+		return
+	}
+	userErr, sysErr, statusCode := dbhelpers.CheckIfCurrentUserCanModifyCDN(inf.Tx.Tx, string(cdnName), inf.User.UserName)
+	if userErr != nil || sysErr != nil {
+		api.HandleErr(w, r, inf.Tx.Tx, statusCode, userErr, sysErr)
+		return
+	}
+
 	row := inf.Tx.Tx.QueryRow(insertQueryV4,
 		job.TTLHours,
 		dsid, // Used in inner select for deliveryservice
@@ -821,7 +832,7 @@ func Create(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
-	w.Header().Set(http.CanonicalHeaderKey("location"), fmt.Sprintf("%s://%s/api/%d.%d/jobs?id=%d", inf.Config.URL.Scheme, r.Host, inf.Version.Major, inf.Version.Minor, *result.ID))
+	w.Header().Set(http.CanonicalHeaderKey("location"), fmt.Sprintf("%s://%s/api/%s/jobs?id=%d", inf.Config.URL.Scheme, r.Host, inf.Version, *result.ID))
 	w.WriteHeader(http.StatusOK)
 	api.WriteAndLogErr(w, r, append(resp, '\n'))
 
@@ -947,7 +958,7 @@ func UpdateV40(w http.ResponseWriter, r *http.Request) {
 
 	if job.InvalidationType != input.InvalidationType {
 		if input.InvalidationType == tc.REFETCH && !refetchAllowed(inf.Tx.Tx) {
-			userErr = errors.New("Invalidation Type REFRESH is disallowed")
+			userErr = errors.New("Invalidation Type REFETCH is disallowed")
 			errCode = http.StatusBadRequest
 			api.HandleErr(w, r, inf.Tx.Tx, errCode, userErr, nil)
 			return
@@ -1444,7 +1455,7 @@ func validateJobCreateV4(job tc.InvalidationJobCreateV4, tx *sql.Tx) error {
 	}
 
 	if job.InvalidationType == tc.REFETCH && !refetchAllowed(tx) {
-		errs = append(errs, "InvalidationType is invalid")
+		errs = append(errs, "invalidationType is not allowed since 'refetch_enabled' parameter doesn't exists or the value is not set to a case-insensitive 'true'")
 	}
 
 	if len(errs) > 0 {
