@@ -34,13 +34,13 @@ import (
 	"path/filepath"
 	"time"
 
-	"github.com/apache/trafficcontrol/lib/go-log"
-	"github.com/apache/trafficcontrol/lib/go-rfc"
-	"github.com/apache/trafficcontrol/lib/go-tc"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/api"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/auth"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/config"
-	"github.com/apache/trafficcontrol/traffic_ops/traffic_ops_golang/tocookie"
+	"github.com/apache/trafficcontrol/v8/lib/go-log"
+	"github.com/apache/trafficcontrol/v8/lib/go-rfc"
+	"github.com/apache/trafficcontrol/v8/lib/go-tc"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/api"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/auth"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/config"
+	"github.com/apache/trafficcontrol/v8/traffic_ops/traffic_ops_golang/tocookie"
 
 	"github.com/jmoiron/sqlx"
 	"github.com/lestrrat-go/jwx/jwa"
@@ -108,135 +108,188 @@ Subject: {{.InstanceName}} Password Reset Request` + "\r\n\r" + `
 </html>
 `))
 
+func clientCertAuthentication(w http.ResponseWriter, r *http.Request, db *sqlx.DB, cfg config.Config, dbCtx context.Context, cancelTx context.CancelFunc, form auth.PasswordForm, authenticated bool) bool {
+	// No certs provided by the client. Skip to form authentication
+	if r.TLS == nil || len(r.TLS.PeerCertificates) == 0 {
+		return false
+	}
+
+	// If no configuration is set, skip to form auth
+	if cfg.ClientCertAuth == nil || len(cfg.ClientCertAuth.RootCertsDir) == 0 {
+		return false
+	}
+
+	// Perform certificate verification to ensure it is valid against Root CAs
+	err := auth.VerifyClientCertificate(r, cfg.ClientCertAuth.RootCertsDir, cfg.Insecure)
+	if err != nil {
+		log.Warnf("client cert auth: error attempting to verify client provided TLS certificate. err: %s\n", err)
+		return false
+	}
+
+	// Client provided a verified certificate. Extract UID value.
+	if username, err := auth.ParseClientCertificateUID(r.TLS.PeerCertificates[0]); err != nil {
+		log.Errorf("parsing client certificate: %s\n", err)
+		return false
+	} else {
+		form.Username = username
+	}
+
+	// Check if user exists locally (TODB) and has a role.
+	var blockingErr error
+	authenticated, err, blockingErr = auth.CheckLocalUserIsAllowed(form.Username, db, dbCtx)
+	if blockingErr != nil {
+		api.HandleErr(w, r, nil, http.StatusServiceUnavailable, nil, fmt.Errorf("error checking local user has role: %s", blockingErr.Error()))
+		return false
+	}
+	if err != nil {
+		log.Warnf("client cert auth: checking local user: %s\n", err)
+	}
+
+	// Check LDAP if enabled
+	if !authenticated && cfg.LDAPEnabled {
+		_, authenticated, err = auth.LookupUserDN(form.Username, cfg.ConfigLDAP)
+		if err != nil {
+			log.Warnf("Client Cert Auth: checking ldap user: %s\n", err)
+		}
+	}
+
+	return authenticated
+}
+
+// LoginHandler first attempts to verify and parse user information from an optionally
+// provided client TLS certificate. If it fails at any point, it will fall back and
+// continue with the standard submitted form authentication.
 func LoginHandler(db *sqlx.DB, cfg config.Config) http.HandlerFunc {
 	return func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
 		authenticated := false
 		form := auth.PasswordForm{}
-		if err := json.NewDecoder(r.Body).Decode(&form); err != nil {
-			api.HandleErr(w, r, nil, http.StatusBadRequest, err, nil)
-			return
-		}
-		if form.Username == "" || form.Password == "" {
-			api.HandleErr(w, r, nil, http.StatusBadRequest, errors.New("username and password are required"), nil)
-			return
-		}
-		resp := struct {
-			tc.Alerts
-		}{}
+		var resp tc.Alerts
 		dbCtx, cancelTx := context.WithTimeout(r.Context(), time.Duration(cfg.DBQueryTimeoutSeconds)*time.Second)
 		defer cancelTx()
-		userAllowed, err, blockingErr := auth.CheckLocalUserIsAllowed(form, db, dbCtx)
-		if blockingErr != nil {
-			api.HandleErr(w, r, nil, http.StatusServiceUnavailable, nil, fmt.Errorf("error checking local user password: %s\n", blockingErr.Error()))
-			return
-		}
-		if err != nil {
-			log.Errorf("checking local user: %s\n", err.Error())
-		}
-		if userAllowed {
-			authenticated, err, blockingErr = auth.CheckLocalUserPassword(form, db, dbCtx)
+
+		// Attempt to perform client certificate authentication. If fails, goto standard form auth. If the
+		// certificate was verified, has a UID, and the UID matches an existing user we consider this to
+		// be a successful login.
+		authenticated = clientCertAuthentication(w, r, db, cfg, dbCtx, cancelTx, form, authenticated)
+
+		// Failed certificate-based auth, perform standard form auth
+		if !authenticated {
+			// Perform form authentication
+			if err := json.NewDecoder(r.Body).Decode(&form); err != nil {
+				api.HandleErr(w, r, nil, http.StatusBadRequest, err, nil)
+				return
+			}
+			if form.Username == "" || form.Password == "" {
+				api.HandleErr(w, r, nil, http.StatusBadRequest, errors.New("username and password are required"), nil)
+				return
+			}
+
+			// Check if user exists and has a role
+			userAllowed, err, blockingErr := auth.CheckLocalUserIsAllowed(form.Username, db, dbCtx)
 			if blockingErr != nil {
-				api.HandleErr(w, r, nil, http.StatusServiceUnavailable, nil, fmt.Errorf("error checking local user password: %s\n", blockingErr.Error()))
+				api.HandleErr(w, r, nil, http.StatusServiceUnavailable, nil, fmt.Errorf("error checking local user has role: %s", blockingErr.Error()))
 				return
 			}
 			if err != nil {
-				log.Errorf("checking local user password: %s\n", err.Error())
+				log.Errorf("checking local user: %s\n", err)
+			}
+
+			// User w/ role does not exist, return unauthorized
+			if !userAllowed {
+				resp = tc.CreateAlerts(tc.ErrorLevel, "Invalid username or password.")
+				w.WriteHeader(http.StatusUnauthorized)
+				api.WriteRespRaw(w, r, resp)
+				return
+			}
+
+			// Check local DB or LDAP
+			authenticated, err, blockingErr = auth.CheckLocalUserPassword(form, db, dbCtx)
+			if blockingErr != nil {
+				api.HandleErr(w, r, nil, http.StatusServiceUnavailable, nil, fmt.Errorf("error checking local user password: %s", blockingErr.Error()))
+				return
+			}
+			if err != nil {
+				log.Errorf("checking local user password: %s\n", err)
 			}
 			var ldapErr error
-			if !authenticated {
-				if cfg.LDAPEnabled {
-					authenticated, ldapErr = auth.CheckLDAPUser(form, cfg.ConfigLDAP)
-					if ldapErr != nil {
-						log.Errorf("checking ldap user: %s\n", ldapErr.Error())
-					}
+			if !authenticated && cfg.LDAPEnabled {
+				authenticated, ldapErr = auth.CheckLDAPUser(form, cfg.ConfigLDAP)
+				if ldapErr != nil {
+					log.Errorf("checking ldap user: %s\n", ldapErr.Error())
 				}
 			}
-			if authenticated {
-				httpCookie := tocookie.GetCookie(form.Username, defaultCookieDuration, cfg.Secrets[0])
-				http.SetCookie(w, httpCookie)
-
-				var jwtToken jwt.Token
-				var jwtSigned []byte
-				jwtBuilder := jwt.NewBuilder()
-
-				emptyConf := config.CdniConf{}
-				if cfg.Cdni != nil && *cfg.Cdni != emptyConf {
-					ucdn, err := auth.GetUserUcdn(form, db, dbCtx)
-					if err != nil {
-						// log but do not error out since this is optional in the JWT for CDNi integration
-						log.Errorf("getting ucdn for user %s: %v", form.Username, err)
-					}
-					jwtBuilder.Claim("iss", ucdn)
-					jwtBuilder.Claim("aud", cfg.Cdni.DCdnId)
-				}
-
-				jwtBuilder.Claim("exp", httpCookie.Expires.Unix())
-				jwtBuilder.Claim(api.MojoCookie, httpCookie.Value)
-				jwtToken, err = jwtBuilder.Build()
-				if err != nil {
-					api.HandleErr(w, r, nil, http.StatusInternalServerError, nil, fmt.Errorf("building token: %s", err))
-					return
-				}
-
-				jwtSigned, err = jwt.Sign(jwtToken, jwa.HS256, []byte(cfg.Secrets[0]))
-				if err != nil {
-					api.HandleErr(w, r, nil, http.StatusInternalServerError, nil, err)
-					return
-				}
-
-				http.SetCookie(w, &http.Cookie{
-					Name:     api.AccessToken,
-					Value:    string(jwtSigned),
-					Path:     "/",
-					MaxAge:   httpCookie.MaxAge,
-					Expires:  httpCookie.Expires,
-					HttpOnly: true, // prevents the cookie being accessed by Javascript. DO NOT remove, security vulnerability
-				})
-
-				// If all's well until here, then update last authenticated time
-				tx, txErr := db.BeginTx(dbCtx, nil)
-				if txErr != nil {
-					api.HandleErr(w, r, tx, http.StatusInternalServerError, nil, fmt.Errorf("beginning transaction: %w", txErr))
-					return
-				}
-				defer func() {
-					if err := tx.Commit(); err != nil && err != sql.ErrTxDone {
-						log.Errorln("committing transaction: " + err.Error())
-					}
-				}()
-				_, dbErr := tx.Exec(UpdateLoginTimeQuery, form.Username)
-				if dbErr != nil {
-					log.Errorf("unable to update authentication time for a given user: %s\n", dbErr.Error())
-					resp = struct {
-						tc.Alerts
-					}{tc.CreateAlerts(tc.ErrorLevel, "Unable to update authentication time for a given user")}
-				} else {
-					resp = struct {
-						tc.Alerts
-					}{tc.CreateAlerts(tc.SuccessLevel, "Successfully logged in.")}
-				}
-
-			} else {
-				resp = struct {
-					tc.Alerts
-				}{tc.CreateAlerts(tc.ErrorLevel, "Invalid username or password.")}
-			}
-		} else {
-			resp = struct {
-				tc.Alerts
-			}{tc.CreateAlerts(tc.ErrorLevel, "Invalid username or password.")}
 		}
-		respBts, err := json.Marshal(resp)
+
+		// Failed to authenticate in either local DB or LDAP, return unauthorized
+		if !authenticated {
+			resp = tc.CreateAlerts(tc.ErrorLevel, "Invalid username or password.")
+			w.WriteHeader(http.StatusUnauthorized)
+			api.WriteRespRaw(w, r, resp)
+			return
+		}
+
+		// Successful authentication, write cookie and return
+		httpCookie := tocookie.GetCookie(form.Username, defaultCookieDuration, cfg.Secrets[0])
+		http.SetCookie(w, httpCookie)
+
+		var jwtToken jwt.Token
+		var jwtSigned []byte
+		jwtBuilder := jwt.NewBuilder()
+
+		emptyConf := config.CdniConf{}
+		if cfg.Cdni != nil && *cfg.Cdni != emptyConf {
+			ucdn, err := auth.GetUserUcdn(form, db, dbCtx)
+			if err != nil {
+				// log but do not error out since this is optional in the JWT for CDNi integration
+				log.Errorf("getting ucdn for user %s: %v", form.Username, err)
+			}
+			jwtBuilder.Claim(jwt.IssuerKey, ucdn)
+			jwtBuilder.Claim(jwt.AudienceKey, cfg.Cdni.DCdnId)
+		}
+
+		jwtBuilder.Claim(jwt.ExpirationKey, httpCookie.Expires.Unix())
+		jwtBuilder.Claim(api.MojoCookie, httpCookie.Value)
+		jwtToken, err := jwtBuilder.Build()
+		if err != nil {
+			api.HandleErr(w, r, nil, http.StatusInternalServerError, nil, fmt.Errorf("building token: %s", err))
+			return
+		}
+
+		jwtSigned, err = jwt.Sign(jwtToken, jwa.HS256, []byte(cfg.Secrets[0]))
 		if err != nil {
 			api.HandleErr(w, r, nil, http.StatusInternalServerError, nil, err)
 			return
 		}
-		w.Header().Set(rfc.ContentType, rfc.ApplicationJSON)
-		if !authenticated {
-			w.WriteHeader(http.StatusUnauthorized)
+
+		http.SetCookie(w, &http.Cookie{
+			Name:     rfc.AccessToken,
+			Value:    string(jwtSigned),
+			Path:     "/",
+			MaxAge:   httpCookie.MaxAge,
+			Expires:  httpCookie.Expires,
+			HttpOnly: true, // prevents the cookie being accessed by Javascript. DO NOT remove, security vulnerability
+		})
+
+		// If all's well until here, then update last authenticated time
+		tx, txErr := db.BeginTx(dbCtx, nil)
+		if txErr != nil {
+			api.HandleErr(w, r, tx, http.StatusInternalServerError, nil, fmt.Errorf("beginning transaction: %w", txErr))
+			return
 		}
-		fmt.Fprintf(w, "%s", respBts)
+		defer func() {
+			if err := tx.Commit(); err != nil && err != sql.ErrTxDone {
+				log.Errorf("committing transaction: %s", err)
+			}
+		}()
+		_, dbErr := tx.Exec(UpdateLoginTimeQuery, form.Username)
+		if dbErr != nil {
+			log.Errorf("unable to update authentication time for a given user: %s\n", dbErr.Error())
+		}
+
+		resp = tc.CreateAlerts(tc.SuccessLevel, "Successfully logged in.")
+		w.WriteHeader(http.StatusOK)
+		api.WriteRespRaw(w, r, resp)
 	}
 }
 
@@ -406,17 +459,17 @@ func OauthLoginHandler(db *sqlx.DB, cfg config.Config) http.HandlerFunc {
 
 		var result map[string]interface{}
 		if err := json.Unmarshal(buf.Bytes(), &result); err != nil {
-			log.Warnf("Error parsing JSON response from oAuth: %s", err.Error())
+			log.Warnf("Error parsing JSON response from OAuth: %s", err)
 			encodedToken = buf.String()
-		} else if _, ok := result[api.AccessToken]; !ok {
+		} else if _, ok := result[rfc.IDToken]; !ok {
 			sysErr := fmt.Errorf("Missing access token in response: %s\n", buf.String())
 			usrErr := errors.New("Bad response from OAuth2.0 provider")
 			api.HandleErr(w, r, nil, http.StatusBadGateway, usrErr, sysErr)
 			return
 		} else {
-			switch t := result[api.AccessToken].(type) {
+			switch t := result[rfc.IDToken].(type) {
 			case string:
-				encodedToken = result[api.AccessToken].(string)
+				encodedToken = result[rfc.IDToken].(string)
 			default:
 				sysErr := fmt.Errorf("Incorrect type of access_token! Expected 'string', got '%v'\n", t)
 				usrErr := errors.New("Bad response from OAuth2.0 provider")
@@ -430,28 +483,46 @@ func OauthLoginHandler(db *sqlx.DB, cfg config.Config) http.HandlerFunc {
 			return
 		}
 
-		decodedToken, err := jwt.Parse(
+		var decodedToken jwt.Token
+		if decodedToken, err = jwt.Parse(
 			[]byte(encodedToken),
 			jwt.WithVerifyAuto(true),
 			jwt.WithJWKSetFetcher(jwksFetcher),
-		)
-		if err != nil {
-			api.HandleErr(w, r, nil, http.StatusInternalServerError, nil, fmt.Errorf("Error decoding token with message: %w", err))
-			return
+		); err != nil {
+			if decodedToken, err = jwt.Parse(
+				[]byte(encodedToken),
+				jwt.WithVerifyAuto(false),
+				jwt.WithJWKSetFetcher(jwksFetcher),
+			); err != nil {
+				api.HandleErr(w, r, nil, http.StatusInternalServerError, nil, fmt.Errorf("error decoding token with message: %w", err))
+				return
+			}
 		}
 
-		userId := decodedToken.Subject()
-		form.Username = userId
+		var userIDInterface interface{}
+		var userID string
+		var ok bool
+		if cfg.OAuthUserAttribute != "" {
+			attributes := decodedToken.PrivateClaims()
+			if userIDInterface, ok = attributes[cfg.OAuthUserAttribute]; !ok {
+				api.HandleErr(w, r, nil, http.StatusInternalServerError, nil, fmt.Errorf("Non-existent OAuth attribute : %s", cfg.OAuthUserAttribute))
+				return
+			}
+			userID = userIDInterface.(string)
+		} else {
+			userID = decodedToken.Subject()
+		}
+		form.Username = userID
 
 		dbCtx, cancelTx := context.WithTimeout(r.Context(), time.Duration(cfg.DBQueryTimeoutSeconds)*time.Second)
 		defer cancelTx()
-		userAllowed, err, blockingErr := auth.CheckLocalUserIsAllowed(form, db, dbCtx)
+		userAllowed, err, blockingErr := auth.CheckLocalUserIsAllowed(form.Username, db, dbCtx)
 		if blockingErr != nil {
 			api.HandleErr(w, r, nil, http.StatusServiceUnavailable, nil, fmt.Errorf("error checking local user password: %s\n", blockingErr.Error()))
 			return
 		}
 		if err != nil {
-			log.Errorf("checking local user: %s\n", err.Error())
+			log.Errorf("checking local user: %s\n", err)
 		}
 
 		if userAllowed {
@@ -461,7 +532,7 @@ func OauthLoginHandler(db *sqlx.DB, cfg config.Config) http.HandlerFunc {
 				api.HandleErr(w, r, nil, http.StatusInternalServerError, nil, dbErr)
 				return
 			}
-			httpCookie := tocookie.GetCookie(userId, defaultCookieDuration, cfg.Secrets[0])
+			httpCookie := tocookie.GetCookie(userID, defaultCookieDuration, cfg.Secrets[0])
 			http.SetCookie(w, httpCookie)
 			resp = struct {
 				tc.Alerts
