@@ -17,13 +17,20 @@
  * under the License.
  */
 
+/**
+ * @param {*} deliveryService
+ * @param {*} job
+ * @param {*} $scope
+ * @param {import("../../../service/utils/FormUtils")} formUtils
+ * @param {import("../../../service/utils/LocationUtils")} locationUtils
+ */
 var FormDeliveryServiceJobController = function(deliveryService, job, $scope, formUtils, locationUtils) {
 
 	$scope.deliveryService = deliveryService;
 
 	$scope.job = job;
 
-	$scope.navigateToPath = locationUtils.navigateToPath;
+	$scope.navigateToPath = (path, unsavedChanges) => locationUtils.navigateToPath(path, unsavedChanges);
 
 	$scope.hasError = formUtils.hasError;
 
